@@ -102,7 +102,11 @@ void set_environment(t_session *session, t_fcgi_buffer *fcgi_buffer) {
 	add_to_environment(fcgi_buffer, "GATEWAY_INTERFACE", "CGI/1.1");
 
 	add_to_environment(fcgi_buffer, "REQUEST_METHOD", session->method);
+#ifdef HAVE_REWRITE
+	add_to_environment(fcgi_buffer, "REQUEST_URI", session->request_uri);
+#else
 	add_to_environment(fcgi_buffer, "REQUEST_URI", session->uri);
+#endif
 	if (session->uri[session->uri_len - 1] == '/') {
 		len1 = session->uri_len;
 		len2 = strlen(session->host->start_file);
@@ -117,7 +121,7 @@ void set_environment(t_session *session, t_fcgi_buffer *fcgi_buffer) {
 		add_to_environment(fcgi_buffer, "SCRIPT_NAME", session->uri);
 	}
 #ifdef HAVE_REWRITE
-	add_to_environment(fcgi_buffer, "SCRIPT_URL", session->script_url);
+	//add_to_environment(fcgi_buffer, "SCRIPT_URL", session->request_uri);
 #endif
 
 	add_to_environment_chroot(session, fcgi_buffer, "SCRIPT_FILENAME", session->file_on_disk);
