@@ -12,7 +12,6 @@
 #include <pthread.h>
 #include <syslog.h>
 #include <grp.h>
-#include <netdb.h>
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
@@ -558,7 +557,6 @@ int fetch_request(t_session *session) {
 
 #ifdef DEBUG
 	set_client_status(session, NULL);
-	fprintf(stderr, "Request size: %ld + %ld\n", header_length, content_length);
 #endif
 
 	return result;
@@ -594,7 +592,7 @@ int parse_request(t_session *session, int total_bytes) {
 	}
 	*(str_end++) = '\0';
 #ifdef HAVE_REWRITE
-	if ((session->script_url = strdup(session->uri)) == NULL) {
+	if ((session->request_uri = strdup(session->uri)) == NULL) {
 		return -1;
 	}
 #endif
@@ -891,16 +889,6 @@ int serve_client(t_session *session) {
 		remove_dangerous_chars(session->vars);
 	}
 
-	if (session->host->require_resolve_ip && (session->ip_resolved == false)) {
-		/* See if the client IP-address is resolvable
-		 */
-		if (gethostbyaddr((unsigned char*)&(session->ip_address), 4, AF_INET) == NULL) {
-			log_error(session, "can't resolve IP");
-			return 403;
-		}
-		session->ip_resolved = true;
-	}
-
 	if (valid_uri(session->uri) == false) {
 		if (session->put_method) {
 			if (session->binding->enable_alter) {
