@@ -3,6 +3,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <sys/socket.h>
+#include "libstr.h"
 #include "libip.h"
 
 int default_ipv4(t_ip_addr *ip_addr) {
@@ -154,3 +155,49 @@ bool ip_in_subnet(t_ip_addr *ip, t_ip_addr *subnet, int mask) {
 
 	return same_ip(&test_ip, subnet);
 }
+
+int parse_ip_port(char *line, t_ip_addr *ip, int *port) {
+	char *s_ip, *s_port, sep = '?';
+
+#ifdef HAVE_IPV6
+	if (split_string(line, &s_ip, &s_port, ']') == 0) {
+		if ((*s_ip != '[') || (*s_port != ':')) {
+			return -1;
+		}
+		s_ip = remove_spaces(s_ip + 1);
+		s_port = remove_spaces(s_port + 1);
+	} else
+#endif
+	if (split_string(line, &s_ip, &s_port, ' ') != 0) {
+		s_port = line + strlen(line);
+		do {
+			if (s_port <= line) {
+				return -1;
+			}
+			s_port--;
+		} while ((*s_port != ':') && (*s_port != '.'));
+		sep = *s_port;
+		*s_port = '\0';
+		s_ip = remove_spaces(s_ip);
+		s_port = remove_spaces(s_port + 1);
+	}
+
+	if (parse_ip(s_ip, ip) == -1) {
+		return -1;
+	} else if ((*port = str2int(s_port)) <= 0) {
+		return -1;
+	}
+
+	if (sep != '?') {
+		if ((ip->family == AF_INET) && (sep != ':')) {
+			return -1;
+		}
+#ifdef HAVE_IPV6
+		if ((ip->family == AF_INET6) && (sep != '.')) {
+			return -1;
+		}
+#endif
+	}
+
+	return 0;
+}
