@@ -138,7 +138,7 @@ void log_request(t_session *session, int code) {
 		str[BUFFER_SIZE] = '\0';
 
 #ifdef HAVE_REWRITE
-		if (session->script_url == NULL) {
+		if (session->request_uri == NULL) {
 #endif
 			uri = secure_string(session->uri);
 			path_info = secure_string(session->path_info);
@@ -146,7 +146,7 @@ void log_request(t_session *session, int code) {
 #ifdef HAVE_REWRITE
 
 		} else {
-			uri = secure_string(session->script_url);
+			uri = secure_string(session->request_uri);
 			path_info = NULL;
 			vars = NULL;
 		}
