@@ -4,14 +4,19 @@
 #include <stdbool.h>
 #include <regex.h>
 
-typedef enum { rw_match_rewrite, rw_match_goto, rw_match_call,
-               rw_match_return, rw_match_exit, rw_call } t_rewrite_action;
-typedef enum { am_nothing, am_return, am_exit } t_after_match;
+#define RW_ERROR        -1
+#define RW_RETURN        0
+#define RW_EXIT          1
+#define RW_DENY_ACCESS 403
+
+typedef enum { rw_match_rewrite, rw_match_goto, rw_match_call, rw_match_return, 
+               rw_match_exit, rw_call, rw_match_deny_access } t_rewrite_action;
+typedef enum { am_nothing, am_return, am_exit } t_after_rewrite;
 
 typedef struct type_rewrite_rule {
 	regex_t pattern;
 	t_rewrite_action action;
-	t_after_match after_match;
+	t_after_rewrite after_rewrite;
 	int match_loop;
 	char *parameter;
 
