@@ -58,7 +58,6 @@ static t_host *new_host(void) {
 		host->execute_cgi        = false;
 		host->show_index         = false;
 		host->use_gz_file        = false;
-		host->require_resolve_ip = false;
 		host->access_list        = NULL;
 		host->alter_list         = NULL;
 		host->alter_fmode        = 0640;
@@ -88,6 +87,7 @@ static t_host *new_host(void) {
 		host->prevent_xss        = false;
 		host->follow_symlinks    = false;
 		host->enable_path_info   = false;
+		host->trigger_on_cgi_status = true;
 		init_charlist(&(host->fast_cgi));
 		host->secure_url         = true;
 
@@ -302,10 +302,10 @@ static int fgets_multi(char *line, int size, FILE *fp) {
 	if ((line == NULL) || (size <= 1)) {
 		return -1;
 	} else if (fgets(line, size, fp) != NULL) {
-		if ((pos = strstr(line, " \\\n")) != NULL) {
-			lines = fgets_multi(pos, size - (pos - line), fp);
-		} else {
+		if ((pos = strstr(line, " \\\n")) == NULL) {
 			lines = 0;
+		} else if ((lines = fgets_multi(pos, size - (pos - line), fp)) == -1) {
+			return -1;
 		}
 		return 1 + lines;
 	} else {
@@ -1103,7 +1103,7 @@ static bool host_setting(char *key, char *value, t_host *host) {
 			return true;
 		}
 	} else if (strcmp(key, "hostname") == 0) {
-		if (parse_charlist(value, &(host->hostname)) == 0) {
+		if (parse_charlist(strlower(value), &(host->hostname)) == 0) {
 			return true;
 		}
 	} else if (strcmp(key, "imagereferer") == 0) {
@@ -1130,10 +1130,6 @@ static bool host_setting(char *key, char *value, t_host *host) {
 		if (parse_charlist(value, &(host->required_binding)) == 0) {
 			return true;
 		}
-	} else if (strcmp(key, "requireresolveip") == 0) {
-		if (parse_yesno(value, &(host->require_resolve_ip)) == 0) {
-			return true;
-		}
 #ifdef HAVE_REWRITE
 	} else if (strcmp(key, "rewriteurl") == 0) {
 		if (parse_charlist(value, &(host->rewrite_rules)) == 0) {
@@ -1144,6 +1140,10 @@ static bool host_setting(char *key, char *value, t_host *host) {
 		if (parse_yesno(value, &(host->secure_url)) == 0) {
 			return true;
 		}
+	} else if (strcmp(key, "triggeroncgistatus") == 0) {
+		if (parse_yesno(value, &(host->trigger_on_cgi_status)) == 0) {
+			return true;
+		}
 	} else if (strcmp(key, "userwebsites") == 0) {
 		if (parse_yesno(value, &(host->user_websites)) == 0) {
 			return true;
@@ -1366,7 +1366,7 @@ static bool binding_setting(char *key, char *value, t_binding *binding) {
 }
 
 static bool fcgi_server_setting(char *key, char *value, t_fcgi_server *fcgi_server) {
-	char *port, *rest;
+	char *rest;
 	t_connect_to *connect_to;
 
 	if (strcmp(key, "connectto") == 0) {
@@ -1380,11 +1380,7 @@ static bool fcgi_server_setting(char *key, char *value, t_fcgi_server *fcgi_serv
 			connect_to->available = true;
 			fcgi_server->connect_to = connect_to;
 
-			if (split_string(value, &value, &port, ' ') != 0) {
-				return false;
-			} else if (parse_ip(value, &(connect_to->host)) == -1) {
-				return false;
-			} else if ((connect_to->port = str2int(port)) <= 0) {
+			if (parse_ip_port(value, &(connect_to->host), &(connect_to->port)) == -1) {
 				return false;
 			}
 			value = rest;
