@@ -147,7 +147,6 @@ typedef struct type_host {
 	bool          execute_cgi;
 	bool          show_index;
 	bool          use_gz_file;
-	bool          require_resolve_ip;
 	char          *login_message;
 	char          *passwordfile;
 	t_auth_method auth_method;
@@ -178,6 +177,7 @@ typedef struct type_host {
 	bool          prevent_xss;
 	bool          follow_symlinks;
 	bool          enable_path_info;
+	bool          trigger_on_cgi_status;
 	t_charlist    fast_cgi;
 
 	struct type_host *next;
