@@ -33,7 +33,7 @@ static void clear_session(t_session *session) {
 	session->uri_len = 0;
 	session->uri_is_dir = false;
 #ifdef HAVE_REWRITE
-	session->script_url = NULL;
+	session->request_uri = NULL;
 #endif
 	session->accept_gzip = false;
 	session->encode_gzip = false;
@@ -96,7 +96,6 @@ void init_session(t_session *session) {
 	session->buffer_size = 0;
 	session->bytes_in_buffer = 0;
 	session->flooding_timer = time(NULL);
-	session->ip_resolved = false;
 
 	clear_session(session);
 }
@@ -111,7 +110,7 @@ void reset_session(t_session *session) {
 	sfree(session->remote_user);
 	sfree(session->path_info);
 #ifdef HAVE_REWRITE
-	sfree(session->script_url);
+	sfree(session->request_uri);
 #endif
 	if (session->uploaded_file != NULL) {
 		unlink(session->uploaded_file);
@@ -460,6 +459,7 @@ void close_socket(t_session *session) {
 
 #ifdef DEBUG
 void set_client_status(t_session *session, char *status) {
+	fprintf(stderr, "Client status: %s\n", status);
 	sfree(session->status);
 	if (status != NULL) {
 		session->status = strdup(status);
