@@ -741,7 +741,7 @@ int execute_cgi(t_session *session) {
 									retval = rs_DISCONNECT;
 									break;
 								}
-							} else if ((code = strcasestr(cgi_info.input_buffer, "Status: ")) != NULL) {
+							} else if (session->host->trigger_on_cgi_status && ((code = strcasestr(cgi_info.input_buffer, "Status: ")) != NULL)) {
 								line = code += 8;
 
 								retval = -1;
