@@ -291,7 +291,7 @@ int check_main_config(char *config_dir) {
 
 	/* Find duplicate ids
 	 */
-	errors += find_duplicates(config, "BindingId", config_dir);
+	//errors += find_duplicates(config, "BindingId", config_dir);
 	errors += find_duplicates(config, "FastCGIid", config_dir);
 	errors += find_duplicates(config, "RewriteId", config_dir);
 
@@ -537,6 +537,10 @@ void check_url_rewrite(char *config_dir, char **rewrite_id) {
 			break;
 		}
 
+		if (*input != '/') {
+			printf("Bad URL: missing leading slash.\n");
+		}
+
 		id = rewrite_id;
 		while (*id != NULL) {
 			if ((result = rewrite_url(url, *id, url_rewrite, &new_url)) == RW_ERROR) {
@@ -553,6 +557,9 @@ void check_url_rewrite(char *config_dir, char **rewrite_id) {
 		}
 
 		if (new_url != NULL) {
+			if (*new_url != '/') {
+				printf("Warning: your new URL is missing a leading slash!\n");
+			}
 			printf("new: %s\n\n", new_url);
 			free(new_url);
 		} else {
